import type { ParserRuleContext, Token } from 'antlr4';
import { CommonTokenStream } from 'antlr4';
import CypherParser, { StatementsOrCommandsContext } from './generated-parser/CypherCmdParser';
import { SyntaxDiagnostic } from './highlighting/syntaxValidation/syntaxValidationHelpers';
export interface ParsingResult {
    query: string;
    parser: CypherParser;
    tokens: Token[];
    result: StatementsOrCommandsContext;
}
export declare enum LabelType {
    nodeLabelType = "Label",
    relLabelType = "Relationship type",
    unknown = "Label or relationship type"
}
export type LabelOrRelType = {
    labeltype: LabelType;
    labelText: string;
    couldCreateNewLabel: boolean;
    line: number;
    column: number;
    offsets: {
        start: number;
        end: number;
    };
};
export interface EnrichedParsingResult extends ParsingResult {
    diagnostics: SyntaxDiagnostic[];
    stopNode: ParserRuleContext;
    collectedLabelOrRelTypes: LabelOrRelType[];
    collectedVariables: string[];
    collectedCommands: ParsedCommand[];
}
export interface ParsingScaffolding {
    query: string;
    parser: CypherParser;
    tokenStream: CommonTokenStream;
}
export declare function createParsingScaffolding(query: string): ParsingScaffolding;
export declare function parse(cypher: string): StatementsOrCommandsContext;
export declare function createParsingResult(parsingScaffolding: ParsingScaffolding): ParsingResult;
type CypherCmd = {
    type: 'cypher';
    query: string;
};
type RuleTokens = {
    start: Token;
    stop: Token;
};
export type ParsedCypherCmd = CypherCmd & RuleTokens;
export type ParsedCommandNoPosition = {
    type: 'cypher';
    query: string;
} | {
    type: 'use';
    database?: string;
} | {
    type: 'clear';
} | {
    type: 'history';
} | {
    type: 'set-parameters';
    parameters: {
        name: string;
        expression: string;
    }[];
} | {
    type: 'list-parameters';
} | {
    type: 'clear-parameters';
} | {
    type: 'parse-error';
};
export type ParsedCommand = ParsedCommandNoPosition & RuleTokens;
declare class ParserWrapper {
    parsingResult?: EnrichedParsingResult;
    parse(query: string): EnrichedParsingResult;
    clearCache(): void;
}
export declare function setConsoleCommandsEnabled(enabled: boolean): void;
export declare function consoleCommandEnabled(): boolean;
export declare const parserWrapper: ParserWrapper;
export {};
